## Contributing to exoplanet

### Reporting issues

If you find a bug or other unexpected behavior while using `exoplanet`, open an issue
on the [GitHub repository](https://github.com/exoplanet-dev/exoplanet/issues) and we
will try to respond and (hopefully) solve the problem in a timely manner. Similarly,
if you have a feature request or question about the library, the best place to post
those is currently on GitHub as an issue, but that is likely change if the user
community grows. If you report an issue, please give the details needed to reproduce
the problem (version of exoplanet, its dependencies, and your platform) and a small
standalone piece of code that demonstrates the problem clearly.


### Contributing code

We welcome contributions to the codebase of all scales from typo fixes to new features,
but if you would like to add a substantial feature, it would be a good idea to first
open an issue that describes your plan so that we can discuss in advance. More details
about the process for contributing can be found in the developer docs at:
https://docs.exoplanet.codes/en/stable/user/dev/.
